pub enum AttributeValue {
Show 39 variants
Address(Address),
Block(Vec<u8>),
Data1(u8),
Data2(u16),
Data4(u32),
Data8(u64),
Data16(u128),
Sdata(i64),
Udata(u64),
ImplicitConst(i64),
Exprloc(Expression),
Flag(bool),
FlagPresent,
UnitRef(UnitEntryId),
DebugInfoRef(DebugInfoRef),
DebugInfoRefSup(DebugInfoOffset),
LineProgramRef,
LocationListRef(LocationListId),
DebugMacinfoRef(DebugMacinfoOffset),
DebugMacroRef(DebugMacroOffset),
RangeListRef(RangeListId),
DebugTypesRef(DebugTypeSignature),
StringRef(StringId),
DebugStrRefSup(DebugStrOffset),
LineStringRef(LineStringId),
String(Vec<u8>),
Encoding(DwAte),
DecimalSign(DwDs),
Endianity(DwEnd),
Accessibility(DwAccess),
Visibility(DwVis),
Virtuality(DwVirtuality),
Language(DwLang),
AddressClass(DwAddr),
IdentifierCase(DwId),
CallingConvention(DwCc),
Inline(DwInl),
Ordering(DwOrd),
FileIndex(Option<FileId>),
}Expand description
The value of an attribute in a DebuggingInformationEntry.
Variants
Address(Address)
“Refers to some location in the address space of the described program.”
Block(Vec<u8>)
A slice of an arbitrary number of bytes.
Data1(u8)
A one byte constant data value. How to interpret the byte depends on context.
From section 7 of the standard: “Depending on context, it may be a signed integer, an unsigned integer, a floating-point constant, or anything else.”
Data2(u16)
A two byte constant data value. How to interpret the bytes depends on context.
This value will be converted to the target endian before writing.
From section 7 of the standard: “Depending on context, it may be a signed integer, an unsigned integer, a floating-point constant, or anything else.”
Data4(u32)
A four byte constant data value. How to interpret the bytes depends on context.
This value will be converted to the target endian before writing.
From section 7 of the standard: “Depending on context, it may be a signed integer, an unsigned integer, a floating-point constant, or anything else.”
Data8(u64)
An eight byte constant data value. How to interpret the bytes depends on context.
This value will be converted to the target endian before writing.
From section 7 of the standard: “Depending on context, it may be a signed integer, an unsigned integer, a floating-point constant, or anything else.”
Data16(u128)
An sixteen byte constant data value. How to interpret the bytes depends on context.
This value will be converted to the target endian before writing.
From section 7 of the standard: “Depending on context, it may be a signed integer, an unsigned integer, a floating-point constant, or anything else.”
Sdata(i64)
A signed integer constant.
Udata(u64)
An unsigned integer constant.
ImplicitConst(i64)
An implicit signed integer constant.
The constant is stored in the abbreviation instead of being repeated for each DIE using it.
This may be used for any attribute value that is a constant, such as
AttributeValue::Language, but you need to specify the raw value
here instead of using a typed constant.
This is treated as Sdata for DWARF version < 5.
Exprloc(Expression)
“The information bytes contain a DWARF expression (see Section 2.5) or location description (see Section 2.6).”
This is treated as Block for DWARF version < 4.
Flag(bool)
A boolean that indicates presence or absence of the attribute.
FlagPresent
An attribute that is always present.
This is treated as Flag(true) for DWARF version < 4.
UnitRef(UnitEntryId)
A reference to a DebuggingInformationEntry in this unit.
DebugInfoRef(DebugInfoRef)
A reference to a DebuggingInformationEntry in a potentially different unit.
DebugInfoRefSup(DebugInfoOffset)
An offset into the .debug_info section of the supplementary object file.
The API does not currently assist with generating this offset. This variant will be removed from the API once support for writing supplementary object files is implemented.
LineProgramRef
A reference to a line number program.
LocationListRef(LocationListId)
A reference to a location list.
DebugMacinfoRef(DebugMacinfoOffset)
An offset into the .debug_macinfo section.
The API does not currently assist with generating this offset.
This variant will be removed from the API once support for writing
.debug_macinfo sections is implemented.
DebugMacroRef(DebugMacroOffset)
An offset into the .debug_macro section.
The API does not currently assist with generating this offset.
This variant will be removed from the API once support for writing
.debug_macro sections is implemented.
RangeListRef(RangeListId)
A reference to a range list.
DebugTypesRef(DebugTypeSignature)
A type signature.
The API does not currently assist with generating this signature.
This variant will be removed from the API once support for writing
.debug_types sections is implemented.
StringRef(StringId)
A reference to a string in the .debug_str section.
DebugStrRefSup(DebugStrOffset)
An offset into the .debug_str section of the supplementary object file.
The API does not currently assist with generating this offset. This variant will be removed from the API once support for writing supplementary object files is implemented.
LineStringRef(LineStringId)
A reference to a string in the .debug_line_str section.
String(Vec<u8>)
A slice of bytes representing a string. Must not include null bytes. Not guaranteed to be UTF-8 or anything like that.
Encoding(DwAte)
The value of a DW_AT_encoding attribute.
DecimalSign(DwDs)
The value of a DW_AT_decimal_sign attribute.
Endianity(DwEnd)
The value of a DW_AT_endianity attribute.
Accessibility(DwAccess)
The value of a DW_AT_accessibility attribute.
Visibility(DwVis)
The value of a DW_AT_visibility attribute.
Virtuality(DwVirtuality)
The value of a DW_AT_virtuality attribute.
Language(DwLang)
The value of a DW_AT_language attribute.
AddressClass(DwAddr)
The value of a DW_AT_address_class attribute.
IdentifierCase(DwId)
The value of a DW_AT_identifier_case attribute.
CallingConvention(DwCc)
The value of a DW_AT_calling_convention attribute.
Inline(DwInl)
The value of a DW_AT_inline attribute.
Ordering(DwOrd)
The value of a DW_AT_ordering attribute.
FileIndex(Option<FileId>)
An index into the filename entries from the line number information table for the unit containing this value.
Implementations