pub enum DebugInfoRef {
Symbol(usize),
Entry(UnitId, UnitEntryId),
}Expand description
A reference to a .debug_info entry.
Variants
Symbol(usize)
An external symbol.
The meaning of this value is decided by the writer, but will typically be an index into a symbol table.
Entry(UnitId, UnitEntryId)
An entry in the same section.
This only supports references in units that are emitted together.