ConvertLineSequence

Struct ConvertLineSequence 

pub struct ConvertLineSequence {
    pub start: Option<u64>,
    pub end: ConvertLineSequenceEnd,
    pub rows: Vec<LineRow>,
}
Fields

start: Option<u64>

The address of the first instruction in the given rows.

This will be None if there was no DW_LNE_set_address instruction.

end: ConvertLineSequenceEnd

The location of the next instruction after the given rows.

rows: Vec<LineRow>

The rows in the sequence.

The LineRow::address fields are set to an offset from Self::start.