LineRow

Struct LineRow 

pub struct LineRow {
    pub address_offset: u64,
    pub op_index: u64,
    pub file: FileId,
    pub line: u64,
    pub column: u64,
    pub discriminator: u64,
    pub is_statement: bool,
    pub basic_block: bool,
    pub prologue_end: bool,
    pub epilogue_begin: bool,
    pub isa: u64,
}
A row in the line number table that corresponds to a machine instruction.

Fields

address_offset: u64

The offset of the instruction from the start address of the sequence.

op_index: u64

The index of an operation within a VLIW instruction.

The index of the first operation is 0. Set to 0 for non-VLIW instructions.

file: FileId

The source file corresponding to the instruction.

line: u64

The line number within the source file.

Lines are numbered beginning at 1. Set to 0 if there is no source line.

column: u64

The column number within the source line.

Columns are numbered beginning at 1. Set to 0 for the “left edge” of the line.

discriminator: u64

An additional discriminator used to distinguish between source locations. This value is assigned arbitrarily by the DWARF producer.

is_statement: bool

Set to true if the instruction is a recommended breakpoint for a statement.

basic_block: bool

Set to true if the instruction is the beginning of a basic block.

prologue_end: bool

Set to true if the instruction is a recommended breakpoint at the entry of a function.

epilogue_begin: bool

Set to true if the instruction is a recommended breakpoint prior to the exit of a function.

isa: u64

The instruction set architecture of the instruction.

Set to 0 for the default ISA. Other values are defined by the architecture ABI.