pub struct StringTable { /* private fields */ }Expand description
A table of strings that will be stored in a .debug_str section.
Implementations
Sourceimpl StringTable
impl StringTable
Sourcepub fn add<T>(&mut self, bytes: T) -> StringId
pub fn add<T>(&mut self, bytes: T) -> StringId
Add a string to the string table and return its id.
If the string already exists, then return the id of the existing string.
Panics
Panics if bytes contains a null byte.
Sourcepub fn offset(&self, id: StringId) -> DebugStrOffset
pub fn offset(&self, id: StringId) -> DebugStrOffset