Reference

Type Alias Reference 

pub type Reference = DebugInfoRef;
👎Deprecated:

Renamed to DebugInfoRef

A reference to a .debug_info entry.

Aliased Type

pub enum Reference {
    Symbol(usize),
    Entry(UnitId, UnitEntryId),
}

Variants



Symbol(usize)

An external symbol.

The meaning of this value is decided by the writer, but will typically be an index into a symbol table.



Entry(UnitId, UnitEntryId)

An entry in the same section.

This only supports references in units that are emitted together.