pub enum ConvertLineRow {
SetAddress(u64),
Row(LineRow),
EndSequence(u64),
}Expand description
The result of ConvertLineProgram::read_row.
Variants
SetAddress(u64)
The address from a DW_LNE_set_address instruction.
All subsequent rows in the sequence will have their address_offset
field set to an offset from this address.
Row(LineRow)
A row produced by the line number program.
EndSequence(u64)
The address offset of the end of the sequence.